@@ -1,6 +1,6 @@
 import re
 import time
-import utils as utils
+from pywebgo import utils
 from .data import DataHandler
 from .elements import ElementsHandler
 from selenium import webdriver
